==> qtjambi-help-5.15-sources.jar: io/qt/help/QHelpIndexModel.java <==
package io.qt.help;


/**
 * <p>Model that supplies index keywords to views</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qhelpindexmodel.html">QHelpIndexModel</a></p>
 */
public final class QHelpIndexModel extends io.qt.core.QStringListModel
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QHelpIndexModel.class);
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qhelpindexmodel.html#indexCreated">QHelpIndexModel::indexCreated()</a></p>
     */
    public final Signal0 indexCreated = new Signal0();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qhelpindexmodel.html#indexCreationStarted">QHelpIndexModel::indexCreationStarted()</a></p>
     */
    public final Signal0 indexCreationStarted = new Signal0();
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qhelpindexmodel.html#createIndex">QHelpIndexModel::createIndex(QString)</a></p>
     */
    @io.qt.QtUninvokable
    public final void createIndex(java.lang.String customFilterName){
        createIndex_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), customFilterName);
    }
    
    @io.qt.QtUninvokable
    private native void createIndex_native_cref_QString(long __this__nativeId, java.lang.String customFilterName);
    
    /**
     * <p>Overloaded function for {@link #filter(java.lang.String, java.lang.String)}
     *  with <code>wildcard = ""</code>.</p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QModelIndex filter(java.lang.String filter) {
        return filter(filter, "");
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qhelpindexmodel.html#filter">QHelpIndexModel::filter(QString,QString)</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QModelIndex filter(java.lang.String filter, java.lang.String wildcard){
        return filter_native_cref_QString_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), filter, wildcard);
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QModelIndex filter_native_cref_QString_cref_QString(long __this__nativeId, java.lang.String filter, java.lang.String wildcard);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qhelpindexmodel.html#helpEngine">QHelpIndexModel::helpEngine()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.help.QHelpEngineCore helpEngine(){
        return helpEngine_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.help.QHelpEngineCore helpEngine_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qhelpindexmodel.html#isCreatingIndex">QHelpIndexModel::isCreatingIndex()const</a></p>
     */
    @io.qt.QtUninvokable
    public final boolean isCreatingIndex(){
        return isCreatingIndex_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean isCreatingIndex_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qhelpindexmodel-obsolete.html#linksForKeyword">QHelpIndexModel::linksForKeyword(QString)const</a></p>
     * 
     * @deprecated Use {@link io.qt.help.QHelpEngineCore#documentsForKeyword(java.lang.String)} instead
     */
    @Deprecated
    @io.qt.QtUninvokable
    public final io.qt.core.QMap<java.lang.String, io.qt.core.QUrl> linksForKeyword(java.lang.String keyword){
        return linksForKeyword_native_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), keyword);
    }
    
    @Deprecated
    @io.qt.QtUninvokable
    private native io.qt.core.QMap<java.lang.String, io.qt.core.QUrl> linksForKeyword_native_cref_QString_constfct(long __this__nativeId, java.lang.String keyword);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QHelpIndexModel(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-help-6.3.0-sources.jar: io/qt/help/QHelpIndexModel.java <==
package io.qt.help;


/**
 * <p>Model that supplies index keywords to views</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qhelpindexmodel.html">QHelpIndexModel</a></p>
 */
public final class QHelpIndexModel extends io.qt.core.QStringListModel
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QHelpIndexModel.class);
    

    /**
     * <p>See <a href="https://doc.qt.io/qt/qhelpindexmodel.html#indexCreated">QHelpIndexModel::indexCreated()</a></p>
     */
    public final Signal0 indexCreated = new Signal0();

    /**
     * <p>See <a href="https://doc.qt.io/qt/qhelpindexmodel.html#indexCreationStarted">QHelpIndexModel::indexCreationStarted()</a></p>
     */
    public final Signal0 indexCreationStarted = new Signal0();
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qhelpindexmodel.html#createIndex">QHelpIndexModel::createIndex(QString)</a></p>
     */
    @io.qt.QtUninvokable
    public final void createIndex(java.lang.String customFilterName){
        createIndex_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), customFilterName);
    }
    
    @io.qt.QtUninvokable
    private native void createIndex_native_cref_QString(long __this__nativeId, java.lang.String customFilterName);
    
    /**
     * <p>Overloaded function for {@link #filter(java.lang.String, java.lang.String)}
     *  with <code>wildcard = ""</code>.</p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QModelIndex filter(java.lang.String filter) {
        return filter(filter, "");
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qhelpindexmodel.html#filter">QHelpIndexModel::filter(QString,QString)</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QModelIndex filter(java.lang.String filter, java.lang.String wildcard){
        return filter_native_cref_QString_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), filter, wildcard);
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QModelIndex filter_native_cref_QString_cref_QString(long __this__nativeId, java.lang.String filter, java.lang.String wildcard);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qhelpindexmodel.html#helpEngine">QHelpIndexModel::helpEngine()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.help.QHelpEngineCore helpEngine(){
        return helpEngine_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.help.QHelpEngineCore helpEngine_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qhelpindexmodel.html#isCreatingIndex">QHelpIndexModel::isCreatingIndex()const</a></p>
     */
    @io.qt.QtUninvokable
    public final boolean isCreatingIndex(){
        return isCreatingIndex_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean isCreatingIndex_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QHelpIndexModel(QPrivateConstructor p) { super(p); } 
    
}
